==> jc-1.4.0.tar.gz: gnu/java/net/GetLocalHostAction.c <==
// public class gnu.java.net.GetLocalHostAction

// class file dependencies
// @dep_class 985e0f9a29adf9b2 gnu_java_net_GetLocalHostAction
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 5c7caaa930e11b7 java_net_InetAddress
// @dep_class 49d704cff607029c java_net_UnknownHostException
// @dep_class fe58a8cfe9b5b994 java_security_PrivilegedAction

// header file dependencies
// @dep_header gnu_java_net_GetLocalHostAction
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_net_InetAddress
// @dep_header java_net_UnknownHostException
// @dep_header java_security_PrivilegedAction

#include "jc_defs.h"

#include "gnu/java/net/GetLocalHostAction.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/net/InetAddress.h"
#include "java/net/UnknownHostException.h"
#include "java/security/PrivilegedAction.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_gnu_java_net_GetLocalHostAction$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_gnu_java_net_GetLocalHostAction$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_gnu_java_net_GetLocalHostAction$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_gnu_java_net_GetLocalHostAction$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_java_net_GetLocalHostAction$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_net_GetLocalHostAction$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_net_GetLocalHostAction$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_net_GetLocalHostAction, _init$52f4ad9f2989aeee);

void
_jc_gnu_java_net_GetLocalHostAction$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_gnu_java_net_GetLocalHostAction$object *this)
{
	struct _jc_gnu_java_net_GetLocalHostAction$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(50);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object run()
//

static _jc_linenum _jc_gnu_java_net_GetLocalHostAction$linenum_table$run$b190d7b16d5785b8[];

static _jc_trap_info _jc_gnu_java_net_GetLocalHostAction$trap_table$run$b190d7b16d5785b8[] = {
	_JC_TRAP(&_jc_java_net_UnknownHostException$type, 1, 2),
};

static const unsigned char _jc_gnu_java_net_GetLocalHostAction$param_ptypes$run$b190d7b16d5785b8[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_java_net_GetLocalHostAction$method_info$run$b190d7b16d5785b8 = {
	.name=			"run",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_gnu_java_net_GetLocalHostAction$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_gnu_java_net_GetLocalHostAction$param_ptypes$run$b190d7b16d5785b8,
	.signature_hash=	_JC_JLONG(0xb190d7b16d5785b8),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_net_GetLocalHostAction$method$run$b190d7b16d5785b8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_java_net_GetLocalHostAction$vtable, gnu_java_net_GetLocalHostAction.run$b190d7b16d5785b8) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .trap_table_len=	1,
	  .trap_table=		_jc_gnu_java_net_GetLocalHostAction$trap_table$run$b190d7b16d5785b8,
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_gnu_java_net_GetLocalHostAction$linenum_table$run$b190d7b16d5785b8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_net_GetLocalHostAction, run$b190d7b16d5785b8);

_jc_java_lang_Object$object *
_jc_gnu_java_net_GetLocalHostAction$method$run$b190d7b16d5785b8(_jc_env *const env, _jc_gnu_java_net_GetLocalHostAction$object *this)
{
	struct _jc_gnu_java_net_GetLocalHostAction$object *r0;
	struct _jc_java_net_UnknownHostException$object *r1;
	struct _jc_java_lang_String$object *r2;
	_jc_object_array *r5;
	struct _jc_java_net_InetAddress$object *r6;
	_jc_catch_frame	catch;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	// Define exception targets
	_JC_DEFINE_TRAPS(env, catch, &_jc_gnu_java_net_GetLocalHostAction$method_info$run$b190d7b16d5785b8, &&label0);

	r0 = this;
	_JC_TRAP_REGION(catch, 1);
	_JC_ACTIVE_USE(env, java_net_InetAddress);
	_JC_LINE_NUMBER(57);				// 0
	r2 = _JC_INVOKE_STATIC(env, java_net_InetAddress, getLocalHostname$a0db534f9a891f36, 1);
	r5 = _JC_INVOKE_STATIC(env, java_net_InetAddress, getAllByName$43eb243dd8df29ec, 1, r2);
	r6 = _JC_REF_ELEMENT(env, r5, 0, 0, 1);
	_JC_TRAP_REGION(catch, 2);
	_JC_CANCEL_TRAPS(env, catch);
	return r6;

label0:
	_JC_TRAP_REGION(catch, 2);
	r1 = _JC_CAUGHT_EXCEPTION(env);
	_JC_LINE_NUMBER(61);				// 1
	_JC_CANCEL_TRAPS(env, catch);
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_java_net_GetLocalHostAction$methods[] = {
	&_jc_gnu_java_net_GetLocalHostAction$method_info$_init$52f4ad9f2989aeee,
	&_jc_gnu_java_net_GetLocalHostAction$method_info$run$b190d7b16d5785b8
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_gnu_java_net_GetLocalHostAction$interfaces[] = {
	&_jc_java_security_PrivilegedAction$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_gnu_java_net_GetLocalHostAction$imethod_hash_bucket_56[] = {
	&_jc_gnu_java_net_GetLocalHostAction$method_info$run$b190d7b16d5785b8,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_gnu_java_net_GetLocalHostAction$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	_jc_gnu_java_net_GetLocalHostAction$imethod_hash_bucket_56
};

// Interface "quick" lookup hash table
static const void *_jc_gnu_java_net_GetLocalHostAction$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	&_jc_gnu_java_net_GetLocalHostAction$method$run$b190d7b16d5785b8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_20[] = {
	&_jc_java_security_PrivilegedAction$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_50[] = {
	&_jc_gnu_java_net_GetLocalHostAction$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_java_net_GetLocalHostAction$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[20]=	_jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_20,
	[50]=	_jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_50,
	[113]=	_jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_java_net_GetLocalHostAction$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/net/InetAddress",	_JC_JLONG(0x5c7caaa930e11b7) },
	{ "java/net/UnknownHostException",	_JC_JLONG(0x49d704cff607029c) },
	{ "java/security/PrivilegedAction",	_JC_JLONG(0xfe58a8cfe9b5b994) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_java_net_GetLocalHostAction$vtype _jc_gnu_java_net_GetLocalHostAction$type = {
    .type= {
	.name=			"gnu/java/net/GetLocalHostAction",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_gnu_java_net_GetLocalHostAction$interfaces) / sizeof(*_jc_gnu_java_net_GetLocalHostAction$interfaces),
	.interfaces=		_jc_gnu_java_net_GetLocalHostAction$interfaces,
	.imethod_hash_table=	_jc_gnu_java_net_GetLocalHostAction$imethod_hash_table,
	.imethod_quick_table=	_jc_gnu_java_net_GetLocalHostAction$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x985e0f9a29adf9b2),
		.source_file=		"GetLocalHostAction.java",
		.instance_size=		sizeof(_jc_gnu_java_net_GetLocalHostAction$refs) + sizeof(_jc_gnu_java_net_GetLocalHostAction$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_gnu_java_net_GetLocalHostAction$methods) / sizeof(*_jc_gnu_java_net_GetLocalHostAction$methods),
		.methods=		_jc_gnu_java_net_GetLocalHostAction$methods,
		.instanceof_hash_table=	_jc_gnu_java_net_GetLocalHostAction$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_java_net_GetLocalHostAction$class_depends) / sizeof(*_jc_gnu_java_net_GetLocalHostAction$class_depends),
		.class_depends=		_jc_gnu_java_net_GetLocalHostAction$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_java_net_GetLocalHostAction= {
	    .run$b190d7b16d5785b8=
		&_jc_gnu_java_net_GetLocalHostAction$method$run$b190d7b16d5785b8,
	},
    }
};

==> jc-1.4.5.tar.gz: gnu/java/net/GetLocalHostAction.c <==
// public class gnu.java.net.GetLocalHostAction

// class file dependencies
// @dep_class 985e0f9a29adf9b2 gnu_java_net_GetLocalHostAction
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class e37fd45d04a32233 java_net_InetAddress
// @dep_class 49d704cff607029c java_net_UnknownHostException
// @dep_class 8d3b914900af17ce java_net_VMInetAddress
// @dep_class fe58a8cfe9b5b994 java_security_PrivilegedAction

// header file dependencies
// @dep_header gnu_java_net_GetLocalHostAction
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_net_InetAddress
// @dep_header java_net_UnknownHostException
// @dep_header java_net_VMInetAddress
// @dep_header java_security_PrivilegedAction

#include "jc_defs.h"

#include "gnu/java/net/GetLocalHostAction.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/net/InetAddress.h"
#include "java/net/UnknownHostException.h"
#include "java/net/VMInetAddress.h"
#include "java/security/PrivilegedAction.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_gnu_java_net_GetLocalHostAction$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_gnu_java_net_GetLocalHostAction$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_gnu_java_net_GetLocalHostAction$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_gnu_java_net_GetLocalHostAction$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_java_net_GetLocalHostAction$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_net_GetLocalHostAction$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_net_GetLocalHostAction$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_net_GetLocalHostAction, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_gnu_java_net_GetLocalHostAction$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_gnu_java_net_GetLocalHostAction$object *this)
{
	struct _jc_gnu_java_net_GetLocalHostAction$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(50);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object run()
//

static _jc_linenum _jc_gnu_java_net_GetLocalHostAction$linenum_table$run$b190d7b16d5785b8[];

static _jc_trap_info _jc_gnu_java_net_GetLocalHostAction$trap_table$run$b190d7b16d5785b8[] = {
	_JC_TRAP(&_jc_java_net_UnknownHostException$type, 1, 2),
};

static const unsigned char _jc_gnu_java_net_GetLocalHostAction$param_ptypes$run$b190d7b16d5785b8[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_java_net_GetLocalHostAction$method_info$run$b190d7b16d5785b8 = {
	.name=			"run",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_gnu_java_net_GetLocalHostAction$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_gnu_java_net_GetLocalHostAction$param_ptypes$run$b190d7b16d5785b8,
	.signature_hash=	_JC_JLONG(0xb190d7b16d5785b8),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_net_GetLocalHostAction$method$run$b190d7b16d5785b8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_java_net_GetLocalHostAction$vtable, gnu_java_net_GetLocalHostAction.run$b190d7b16d5785b8) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .trap_table_len=	1,
	  .trap_table=		_jc_gnu_java_net_GetLocalHostAction$trap_table$run$b190d7b16d5785b8,
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_gnu_java_net_GetLocalHostAction$linenum_table$run$b190d7b16d5785b8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_net_GetLocalHostAction, run$b190d7b16d5785b8);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_gnu_java_net_GetLocalHostAction$method$run$b190d7b16d5785b8(_jc_env *const env, _jc_gnu_java_net_GetLocalHostAction$object *this)
{
	struct _jc_gnu_java_net_GetLocalHostAction$object *r0;
	struct _jc_java_net_UnknownHostException$object *r1;
	struct _jc_java_lang_String$object *r2;
	_jc_object_array *r5;
	struct _jc_java_net_InetAddress$object *r6;
	_jc_catch_frame	catch;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	// Define exception targets
	_JC_DEFINE_TRAPS(env, catch, &_jc_gnu_java_net_GetLocalHostAction$method_info$run$b190d7b16d5785b8, &&label0);

	r0 = this;
	_JC_TRAP_REGION(catch, 1);
	_JC_ACTIVE_USE(env, java_net_InetAddress);
	_JC_LINE_NUMBER(57);				// 0
	r2 = _JC_INVOKE_STATIC(env, java_net_VMInetAddress, getLocalHostname$a0db534f9a891f36, 0);
	r5 = _JC_INVOKE_STATIC(env, java_net_InetAddress, getAllByName$43eb243dd8df29ec, 1, r2);
	r6 = _JC_REF_ELEMENT(env, r5, 0, 0, 1);
	_JC_TRAP_REGION(catch, 2);
	_JC_CANCEL_TRAPS(env, catch);
	return r6;

label0:
	_JC_TRAP_REGION(catch, 2);
	r1 = _JC_CAUGHT_EXCEPTION(env);
	_JC_LINE_NUMBER(61);				// 1
	_JC_CANCEL_TRAPS(env, catch);
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_java_net_GetLocalHostAction$methods[] = {
	&_jc_gnu_java_net_GetLocalHostAction$method_info$_init$52f4ad9f2989aeee,
	&_jc_gnu_java_net_GetLocalHostAction$method_info$run$b190d7b16d5785b8
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_gnu_java_net_GetLocalHostAction$interfaces[] = {
	&_jc_java_security_PrivilegedAction$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_gnu_java_net_GetLocalHostAction$imethod_hash_bucket_56[] = {
	&_jc_gnu_java_net_GetLocalHostAction$method_info$run$b190d7b16d5785b8,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_gnu_java_net_GetLocalHostAction$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	_jc_gnu_java_net_GetLocalHostAction$imethod_hash_bucket_56
};

// Interface "quick" lookup hash table
static const void *_jc_gnu_java_net_GetLocalHostAction$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	&_jc_gnu_java_net_GetLocalHostAction$method$run$b190d7b16d5785b8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_20[] = {
	&_jc_java_security_PrivilegedAction$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_50[] = {
	&_jc_gnu_java_net_GetLocalHostAction$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_java_net_GetLocalHostAction$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[20]=	_jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_20,
	[50]=	_jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_50,
	[101]=	_jc_gnu_java_net_GetLocalHostAction$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_java_net_GetLocalHostAction$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/net/InetAddress",	_JC_JLONG(0xe37fd45d04a32233) },
	{ "java/net/UnknownHostException",	_JC_JLONG(0x49d704cff607029c) },
	{ "java/net/VMInetAddress",	_JC_JLONG(0x8d3b914900af17ce) },
	{ "java/security/PrivilegedAction",	_JC_JLONG(0xfe58a8cfe9b5b994) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_java_net_GetLocalHostAction$vtype _jc_gnu_java_net_GetLocalHostAction$type = {
    .type= {
	.name=			"gnu/java/net/GetLocalHostAction",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_gnu_java_net_GetLocalHostAction$interfaces) / sizeof(*_jc_gnu_java_net_GetLocalHostAction$interfaces),
	.interfaces=		_jc_gnu_java_net_GetLocalHostAction$interfaces,
	.imethod_hash_table=	_jc_gnu_java_net_GetLocalHostAction$imethod_hash_table,
	.imethod_quick_table=	_jc_gnu_java_net_GetLocalHostAction$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x985e0f9a29adf9b2),
		.source_file=		"GetLocalHostAction.java",
		.instance_size=		sizeof(_jc_gnu_java_net_GetLocalHostAction$refs) + sizeof(_jc_gnu_java_net_GetLocalHostAction$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_gnu_java_net_GetLocalHostAction$methods) / sizeof(*_jc_gnu_java_net_GetLocalHostAction$methods),
		.methods=		_jc_gnu_java_net_GetLocalHostAction$methods,
		.instanceof_hash_table=	_jc_gnu_java_net_GetLocalHostAction$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_java_net_GetLocalHostAction$class_depends) / sizeof(*_jc_gnu_java_net_GetLocalHostAction$class_depends),
		.class_depends=		_jc_gnu_java_net_GetLocalHostAction$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_java_net_GetLocalHostAction= {
	    .run$b190d7b16d5785b8=
		&_jc_gnu_java_net_GetLocalHostAction$method$run$b190d7b16d5785b8,
	},
    }
};
